@@ -20,7 +20,6 @@
 #'
 #' @importFrom sf read_sf st_crs st_filter st_transform st_crs<-
 #' @importFrom archive archive archive_extract
-#' @importFrom dplyr pull
 #' @importFrom utils download.file
 #'
 #' @examples
@@ -45,28 +44,19 @@
 #'
 get_raw_lidar <- function(shape, destfile = ".", grid_path = ".", quiet = F){
 
-   default <- options("timeout")
-   options("timeout" = 3600)
-   on.exit(options(default))
-
    grid <- get_lidar_grid(grid_path, quiet = quiet)
    shape <- st_transform(shape, 2154)
 
-   urls <- grid %>%
-      st_filter(shape, .predicate = st_intersects) %>%
-      pull("url_telech")
+   urls <- grid |>
+      st_filter(shape, .predicate = st_intersects)
+   urls <- urls$url_telech
 
    if (identical(urls, character(0))){
-      return(warning("There is no lidar data on this area"))
+      return(warning("There is no lidar data on this area."))
    }
 
    already_dowload <- paste(list.files(destfile, pattern = "LIDARHD"), collapse = "|")
-   urls <- urls[!grepl(already_dowload, urls)]
-
-   # allow 1h of downloadin
-   default <- options("timeout")
-   options("timeout" = 3600)
-   on.exit(options(default))
+   urls <- urls[!(urls %in% already_dowload)]
 
    if(length(urls) != 0){
       message ("Tiles to download : ", length(urls))
